#!/usr/bin/env python
# Author:      E. Feng (Chicago) <Eric.Feng@cern.ch>
# Modified:    B. Samset (UiO) <b.h.samset@fys.uio.no> for use with SUSYD3PDs
# Usage:
#  ./SlimD3PD.py file1.root,file2.root,...

treename = 'susy'
branches = [    

# general
'RunNumber','EventNumber','lbn','bcid','mcevt_weight','mcevt_pileUpType','larError','timestamp',
'top_hfor_type','actualIntPerXing','averageIntPerXing','mcevt_pdf*', 'mc_channel_number',
# triggers
'EF_2b15_medium_3L1J15','EF_2b20_medium_3L1J20',
# Trigger matching
'trig_EF_el_n','trig_EF_el_eta','trig_EF_el_phi',
# Etmiss
'MET_Simplified20_RefFinal_etx*','MET_Simplified20_RefFinal_ety*','MET_Simplified20_RefFinal_sumet*',
# jets (+ b-tagging info)
'jet_AntiKt4TopoNewEM_n','jet_AntiKt4TopoNewEM_pt','jet_AntiKt4TopoNewEM_eta',
# electrons
'el_n','el_charge','el_pt','el_eta','el_phi','el_E',
# muons
'mu_staco_n','mu_staco_charge',
'vx_n','vx_nTracks','mcVx_n','vx_sumPt'

]

from ROOT import *
import sys
print "sys.argv = ", sys.argv
if not len(sys.argv)>=2:  raise(Exception, "Must specify inputFiles as argument!")
   
inputFiles = sys.argv[1].split(',')
print "inputFiles = ", inputFiles
ch = TChain(treename)
for file in inputFiles:
    ch.Add(file)
nEntries = ch.GetEntries()
print "nEntries = ", nEntries

#################GRL###############################

gSystem.Load('libGoodRunsListsLib')
reader1 = Root.TGoodRunsListReader('data11_7TeV.periodAllYear_DetStatus-v36-pro10_CoolRunQuery-00-04-08_Top_allchannels.xml')
#
reader1.Interpret()
goodrunslist1 = reader1.GetMergedGRLCollection()

####################################################

# All off first
ch.SetBranchStatus("*",0)
# Turn on just what we need
[ ch.SetBranchStatus(branchname, 1) for branchname in branches ]
# Write to new file
outFile = "%s.root" % treename
newFile = TFile(outFile, "RECREATE")
maxEntries = -1
#maxEntries = 100
if (maxEntries!=-1 and nEntries>maxEntries):  nEntries = maxEntries
ch_new = ch.CloneTree(0)
h1 = TH1F ("N_tot","N_tot",3,0.0,3.0)
h2 = TH1F ("N_GRL","N_GRL",3,0.0,3.0)
h3 = TH1F ("N_skim","N_skim",3,0.0,3.0)
for i in range(nEntries):
    ch.GetEntry(i)
    h1.Fill(1)
    if goodrunslist1.HasRunLumiBlock(ch.RunNumber,ch.lbn):
       h2.Fill(1)
       if (i%10000==0):  print "Processing event nr. %i of %i" % (i,nEntries)
       if (ch.EF_2b15_medium_3L1J15>0 or ch.EF_2b20_medium_3L1J20>0 or ch.EF_4j40_a4tc_EFFS>0 or ch.EF_4j45_a4tc_EFFS>0 or ch.EF_5j30_a4tc_EFFS>0 or ch.EF_5j40_a4tc_EFFS>0):
	   if (ch.jet_AntiKt4TopoNewEM_n>0 and ch.vx_nTracks[0] > 4):
               ch_new.Fill()
    	       h3.Fill(1)
ch_new.Print()
h1.Write()
h2.Write()
h3.Write()
# use GetCurrentFile just in case we went over the
# (customizable) maximum file size
ch_new.GetCurrentFile().Write()
ch_new.GetCurrentFile().Close()
